Downloads and caches the Defense Casualty Analysis System (DCAS) Vietnam Conflict Extract Data File, recording U.S. military personnel killed in the Vietnam War (records span 1956 to 2006).
Format
A data frame with 58,220 rows and 55 variables. Key variables include:
- member_name
Name of the service member.
- member_service_code
Service branch code.
- member_service_name
Service branch.
- member_rank_or_rate
Rank or rate.
- person_type_name
Personnel category.
- member_component_code
Service component code.
U.S. National Archives and Records Administration (NARA), College Park, MD. Defense Casualty Analysis System (DCAS) Vietnam Conflict Extract Data File. See Smith (2025) and its Online Appendix for full archival accession details.
References
Smith, Gregory L. (2025). "Beyond body counts: Vietnam war ground combat data." Conflict Management and Peace Science. doi:10.1177/07388942251391081
Examples
if (FALSE) { # \dontrun{
dcas <- get_dcas()
head(dcas)
} # }