Downloads and caches the Southeast Asia Forces Activity (SEAFA) dataset recording monthly locations of American, South Vietnamese, and Allied maneuver battalions in Southeast Asia from 1966 to 1972.
Format
A data frame with 15 variables (row count varies by version). Key variables include:
- unit_number
Unit number.
- record_date
Date of the location record.
- unit_name
Unit name.
- province
Province.
- lat, lng
Geographic coordinates.
- vc_military_region
Viet Cong military region.
U.S. National Archives and Records Administration (NARA), College Park, MD. Electronic records collected by the U.S. Military Assistance Command, Vietnam (MACV). Source file: Southeast Asia Forces Activity (SEAFA). See Smith (2025) and its Online Appendix for full archival accession details.
References
Smith, Gregory L. (2025). "Beyond body counts: Vietnam war ground combat data." Conflict Management and Peace Science. doi:10.1177/07388942251391081
Examples
if (FALSE) { # \dontrun{
seafa <- get_seafa()
head(seafa)
} # }